@@ -14,7 +14,10 @@ import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdktf/tf-module-stack", "1.1.9", __name__[0:-6], "tf-module-stack@1.1.9.jsii.tgz"
+    "@cdktf/tf-module-stack",
+    "1.1.10",
+    __name__[0:-6],
+    "tf-module-stack@1.1.10.jsii.tgz",
 )
 
 __all__ = [
